//+------------------------------------------------------------------+
//|                                                  SimpleTable.mqh |
//|                        Copyright 2012, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2012, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
#include<ChartObjects\ChartObjectsTxtControls.mqh>
//+------------------------------------------------------------------+
//|                                         |
//+------------------------------------------------------------------+
class CColumn
  {
private:
   //---      
   int               m_x;
   int               m_y;
   //---     
   int               m_width;
   int               m_height;
   //---     
   color             m_backcolor;
   color             m_bordercolor;
   //---       
   int               m_total;
   CChartObjectEdit  m_items[];
   //---   
   ENUM_ALIGN_MODE   m_align;
   //---
   color             m_textcolor;
public:
   //---   
                     CColumn(void):m_total(0){ };
                    ~CColumn(void){};
   //---  
   void              Create(const int X,const int Y,const int w,const int h);
   //---     
   void              BackColor(const color clr);
   void              BorderColor(const color clr);
   //---  
   void              TextAlign(const ENUM_ALIGN_MODE align);
   //---
   void              Color(const color clr);
   //---    
   void              AddItem(string name,string value);
   //---  
   void              SetValue(const int index,const string svalue);
   //---  
   void              DeleteAll(void);
  };
//+------------------------------------------------------------------+
//|                                                       |
//+------------------------------------------------------------------+
void CColumn::Create(const int X,const int Y,const int w,const int h)
  {
   m_x=X;
   m_y=Y;
   m_width=w;
   m_height=h;
  }
//+------------------------------------------------------------------+
//|                                                |
//+------------------------------------------------------------------+
void CColumn::TextAlign(const ENUM_ALIGN_MODE align)
  {
//---   
   m_align=align;
//---      
   for(int i=0;i<m_total;i++)
     {
      m_items[i].TextAlign(m_align);
     }
  }
//+------------------------------------------------------------------+
//|                                              |
//+------------------------------------------------------------------+
void CColumn::Color(const color clr)
  {
   m_textcolor=clr;
//---      
   for(int i=0;i<m_total;i++) m_items[i].Color(m_textcolor);
//---
  }
//+------------------------------------------------------------------+
//|                                       |
//+------------------------------------------------------------------+
void CColumn::BackColor(const color clr)
  {
   m_backcolor=clr;
   for(int i=0;i<m_total;i++) m_items[i].BackColor(m_backcolor);
//---
  }
//+------------------------------------------------------------------+
//|                                               |
//+------------------------------------------------------------------+
void CColumn::BorderColor(const color clr)
  {
   m_bordercolor=clr;
   for(int i=0;i<m_total;i++) m_items[i].BorderColor(m_bordercolor);
  }
//+------------------------------------------------------------------+
//|                               |
//+------------------------------------------------------------------+
void CColumn::AddItem(string name,string value)
  {
//---   
   int size=ArraySize(m_items);
   int new_size;
   if((new_size=ArrayResize(m_items,size+1))!=-1) m_total=new_size;
//---   Y     
   int curr_y=m_y+m_height*size;
//---  
   if(m_items[size].Create(0,name,0,m_x,curr_y,m_width,m_height))
     {
      m_items[size].BorderColor(m_bordercolor);
      m_items[size].BackColor(m_backcolor);
      m_items[size].Color(m_textcolor);
      m_items[size].Description(value);
      m_items[size].TextAlign(m_align);
     }
   else  Comment(__FUNCTION__," ",GetLastError());
//---
  }
//+------------------------------------------------------------------+
//|                                           |
//+------------------------------------------------------------------+
void CColumn::SetValue(const int index,const string svalue)
  {
   if(index<m_total) m_items[index].Description(svalue);
//---  
  }
//+------------------------------------------------------------------+
//|                                              |
//+------------------------------------------------------------------+
void CColumn::DeleteAll(void)
  {
//---     
   if(m_total>0)
     {
      //---     
      for(int i=m_total-1;i>=0;i--)
        {
         string n=m_items[i].Name();
         if(!m_items[i].Delete()) Print(__FUNCTION__,"   .  ",GetLastError());
         ResetLastError();
        }
     }
//---    
  }
//+------------------------------------------------------------------+
//|                                 |
//+------------------------------------------------------------------+
class CSimpleTable
  {
private:
   string            m_name;           //  
   int               m_x;              // X    
   int               m_y;              // Y    
   color             m_backcolor;      //  
   color             m_bordercolor;    //  
   color             m_textcolor;      //  
   CColumn           m_columns[2];     //   
   int               m_rows;           //  
public:
   //--- /
                     CSimpleTable();
                    ~CSimpleTable();
   //--- 
   void              Create(const string name,const int X,const int Y,const int w1,const int w2,const int h);
   //---  
   void              BackColor(const color clr);
   void              BorderColor(const color clr);
   void              TextColor(const color clr);
   //---    
   void              AddRow(const string left_cell,const string right_cell);
   //---    
   int               Rows(void) {return (m_rows);};
   //---       
   void              SetValue(const int col,const int row,const string sval);
  };
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
CSimpleTable::Create(const string name,const int X,const int Y,const int w1,const int w2,const int h)
  {
//---
   m_name=name;
   m_x=X;
   m_y=Y;
//---     
   m_columns[0].Create(X,Y,w1,h);
   m_columns[0].TextAlign(ALIGN_LEFT);
//---     
   m_columns[1].Create(X+w1,Y,w2,h);
   m_columns[1].TextAlign(ALIGN_RIGHT);
//---
  }
//+------------------------------------------------------------------+
//|                                                       |
//+------------------------------------------------------------------+
CSimpleTable::CSimpleTable(): m_rows(0)
  {
//---      ,  
   MathSrand(GetTickCount());
  }
//+------------------------------------------------------------------+
//|                                                        |
//+------------------------------------------------------------------+
CSimpleTable::~CSimpleTable()
  {
  }
//+------------------------------------------------------------------+
//|                                                   |
//+------------------------------------------------------------------+
void CSimpleTable::BackColor(const color clr)
  {
   m_backcolor=clr;
   m_columns[0].BackColor(m_backcolor);
   m_columns[1].BackColor(m_backcolor);
  }
//+------------------------------------------------------------------+
//|                                                  |
//+------------------------------------------------------------------+
void CSimpleTable::BorderColor(const color clr)
  {
   m_bordercolor=clr;
   m_columns[0].BorderColor(m_bordercolor);
   m_columns[1].BorderColor(m_bordercolor);
  }
//+------------------------------------------------------------------+
//|                                                 |
//+------------------------------------------------------------------+
void CSimpleTable::TextColor(const color clr)
  {
   m_textcolor=clr;
   m_columns[0].Color(m_textcolor);
   m_columns[1].Color(m_textcolor);
  }
//+------------------------------------------------------------------+
//|                                                  |
//+------------------------------------------------------------------+
void CSimpleTable::AddRow(const string left_cell,const string right_cell)
  {
   string cell_name=m_name+"_c1_"+(string)MathRand();
   //PrintFormat("1.   %s",cell_name);
   m_columns[0].AddItem(cell_name,left_cell);
   cell_name=m_name+"_c2_"+(string)MathRand();
   //PrintFormat("2.   %s",cell_name);
   m_columns[1].AddItem(cell_name,right_cell);
//---  
   m_rows++;
  }
//+------------------------------------------------------------------+
//| /                              |
//+------------------------------------------------------------------+
void CSimpleTable::SetValue(const int col,const int row,const string sval)
  {
   if(col>1 || col<0) return;
   if(row>m_rows) return;
   m_columns[col].SetValue(row,sval);
  }
//+------------------------------------------------------------------+
